@@ -97,10 +97,12 @@ class Layer(Persistable):
 
     def build_layout(self):
         grid = self.grid
-        data = []
         if grid.init:
-            for tile in grid.tiles:
-                pass
+            return {
+                'name': self.name,
+                'layout': grid.build_layout(),
+                'init': True
+            }
         else:
             return {
                 'name': self.name,
